"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const utils_general_1 = require("@energyweb/utils-general");
const PublicIssuer_1 = require("./wrappedContracts/PublicIssuer");
const PrivateIssuer_1 = require("./wrappedContracts/PrivateIssuer");
const Registry_1 = require("./wrappedContracts/Registry");
const PublicIssuer_json_1 = __importDefault(require("../build/contracts/PublicIssuer.json"));
const PrivateIssuer_json_1 = __importDefault(require("../build/contracts/PrivateIssuer.json"));
const Registry_json_1 = __importDefault(require("../build/contracts/Registry.json"));
async function migratePublicIssuer(web3, deployKey, registryAddress) {
    const privateKeyDeployment = deployKey.startsWith('0x') ? deployKey : `0x${deployKey}`;
    const publicIssuerAddress = (await utils_general_1.deploy(web3, PublicIssuer_json_1.default.bytecode, {
        privateKey: privateKeyDeployment
    })).contractAddress;
    const publicIssuer = new PublicIssuer_1.PublicIssuer(web3, publicIssuerAddress);
    await publicIssuer.initialize(registryAddress, {
        privateKey: privateKeyDeployment
    });
    const version = await publicIssuer.version();
    console.log(`PublicIssuer ${version} created at ${publicIssuerAddress}`);
    return publicIssuer;
}
exports.migratePublicIssuer = migratePublicIssuer;
async function migratePrivateIssuer(web3, deployKey, registryAddress, publicIssuerAddress) {
    const privateKeyDeployment = deployKey.startsWith('0x') ? deployKey : `0x${deployKey}`;
    const privateIssuerAddress = (await utils_general_1.deploy(web3, PrivateIssuer_json_1.default.bytecode, {
        privateKey: privateKeyDeployment
    })).contractAddress;
    const privateIssuer = new PrivateIssuer_1.PrivateIssuer(web3, privateIssuerAddress);
    await privateIssuer.initialize(registryAddress, publicIssuerAddress, {
        privateKey: privateKeyDeployment
    });
    const version = await privateIssuer.version();
    console.log(`PrivateIssuer ${version} created at ${privateIssuerAddress}`);
    return privateIssuer;
}
exports.migratePrivateIssuer = migratePrivateIssuer;
async function migrateRegistry(web3, deployKey) {
    const privateKeyDeployment = deployKey.startsWith('0x') ? deployKey : `0x${deployKey}`;
    const registryAddress = (await utils_general_1.deploy(web3, Registry_json_1.default.bytecode, {
        privateKey: privateKeyDeployment
    })).contractAddress;
    const registry = new Registry_1.Registry(web3, registryAddress);
    await registry.initialize({
        privateKey: privateKeyDeployment
    });
    console.log(`Registry created at ${registryAddress}`);
    return registry;
}
exports.migrateRegistry = migrateRegistry;
//# sourceMappingURL=migrate.js.map